@@ -3,7 +3,7 @@
 #' Perform temporal disaggregation or interpolation of low frequency to high
 #' frequency time series. `td` can be used with objects of class
 #' `"ts"`, with numeric vectors or with any
-#' [ts-boxable](https://www.tsbox.help) time series object.
+#' [ts-boxable](https://docs.ropensci.org/tsbox/) time series object.
 #'
 #' `td` is used to disaggregate or interpolate a low frequency to a higher
 #' frequency time series, while either the sum, the average, the first or the
@@ -63,7 +63,7 @@
 #' same results as "denton-cholette" with `h = 1`, but is much faster.
 #'
 #' `"uniform"` is a special case of the `"denton"` approach, with
-#' `h` equals  `0` and `criterion` equals  `"proportional"`.
+#' `h` equals  `0` and `criterion` equals  `"additive"`.
 #' It distributes the residuals uniformly. If no indicator is used, this leads
 #' to a step-shaped series.
 #'
@@ -87,7 +87,7 @@
 #'   (`"quarter"` (or `"quarterly"`), `"month"` (or `"monthly"`), `"day"`,
 #'   `"hour"`, `"minute"`, `"second"`, or `"year"`)
 #'   or as a scalar (e.g. `2`, `4`, `7`, `12`). Required if no right hand side
-#'   indicator series is provided. The [tsbox](https://www.tsbox.help) package must
+#'   indicator series is provided. The [tsbox](https://docs.ropensci.org/tsbox/) package must
 #'   be installed to deal with frequencies other than monthly or quarterly. If
 #'   the input series are numeric, `to` is a scalar indicating the
 #'   frequency ratio.
@@ -153,8 +153,7 @@
 #'   Wei, W. W. S. (1994). Time series analysis. Addison-Wesley publ.
 #'
 #'   Sax, C. und Steiner, P. (2013). Temporal Disaggregation of Time Series.
-#'   *The R Journal*, 5(2), 80-88.
-#'   <https://doi.org/10.32614/RJ-2013-028>
+#'   *The R Journal*, 5(2), 80-88. \doi{10.32614/RJ-2013-028}
 #'
 #' @seealso [ta()] for temporal aggregation, the inverse function of
 #'   `td`.
@@ -224,7 +223,7 @@
 #'
 #' \dontrun{
 #'
-#' # Using altvernative time series classes (see www.tsbox.help)
+#' # Using altvernative time series classes (see https://docs.ropensci.org/tsbox/)
 #' library(tsbox)
 #' sales.a.xts <- ts_xts(window(sales.a, start = 2000))
 #' exports.q.xts <- ts_xts(window(exports.q, start = 2000))
@@ -375,10 +374,10 @@ td <- function(formula, conversion = "sum", to = "quarterly",
         message("High frequency series shorter than low frequency. Discarding low frequency before ", lf[1], ".")
       }
 
-      # last time stamp covered by lf, in hf units. This could be indered from hf
+      # last time stamp covered by lf, in hf units. This could be infered from hf
       # and lf only.
       hf.by.string <- paste0("-", if (!grepl("^\\d", to)) "1 ", to)
-      lf.end <- tsbox::ts_lag(tail(tsbox::ts_bind(lf.dt, NA), 1), by = hf.by.string)$time
+      lf.end <- tail(tsbox::ts_lag(tsbox::ts_bind(lf.dt, NA), by = hf.by.string)$time, 1)
 
       # data matrices
       hf.env <- list2env(as.list(X.matrices))
@@ -392,7 +391,7 @@ td <- function(formula, conversion = "sum", to = "quarterly",
       to <- gsub("daily$", "day", to)
       to <- gsub("ly$", "", to)
       hf.by.string <- paste0("-", if (!grepl("^\\d", to)) "1 ", to)
-      lf.end <- tsbox::ts_lag(tail(tsbox::ts_bind(lf.dt, NA), 1), by = hf.by.string)$time
+      lf.end <- tail(tsbox::ts_lag(tsbox::ts_bind(lf.dt, NA), by = hf.by.string)$time, 1)
       hf.dt <- tsbox::ts_dts(data.frame(time = seq(lf[1], lf.end, by = to), value = 1))
       X.template <- tsbox::copy_class(hf.dt, y_l.series)
       X <- as.matrix(hf.dt$value)
